@@ -3,13 +3,11 @@ from ark_nlp.nn.base.basemodel import BasicModule
 from ark_nlp.nn.base.textcnn import TextCNN
 from ark_nlp.nn.base.rnn import RNN
 
-from ark_nlp.nn.base.bert import VanillaBert
 from ark_nlp.nn.base.bert import Bert
 from ark_nlp.nn.base.ernie import Ernie
 from ark_nlp.nn.base.nezha import NeZha
 from ark_nlp.nn.base.roformer import RoFormer
 
-from ark_nlp.nn.casrel_bert import CasrelBert
 from ark_nlp.nn.biaffine_bert import BiaffineBert
 from ark_nlp.nn.span_bert import SpanBert
 from ark_nlp.nn.global_pointer_bert import GlobalPointerBert
