@@ -1,10 +1,3 @@
-import time
-import torch
-import math
-import torch.nn.functional as F
-from torch import nn
-from transformers import BertModel
-from transformers import BertPreTrainedModel
 from ark_nlp.nn.base.bert import BertForTokenClassification
 from ark_nlp.nn.layer.crf_block import CRF
 
@@ -13,17 +6,18 @@ class CrfBert(BertForTokenClassification):
     """
     基于BERT + CRF 的命名实体模型
 
-    :param config: (obejct) 模型的配置对象
-    :param bert_trained: (bool) bert参数是否可训练，默认可训练
-
-    :returns: 
-    """ 
+    Args:
+        config: 
+            模型的配置对象
+        encoder_trained (:obj:`bool`, optional, defaults to True):
+            bert参数是否可训练，默认可训练
+    """  # noqa: ignore flake8"
 
     def __init__(
-        self, 
-        config, 
+        self,
+        config,
         encoder_trained=True
     ):
         super(CrfBert, self).__init__(config, encoder_trained)
 
-        self.crf = CRF(num_tags=config.num_labels, batch_first=True)
\ No newline at end of file
+        self.crf = CRF(num_tags=config.num_labels, batch_first=True)
