@@ -1,9 +1,7 @@
-import math
 import torch
 import torch.nn as nn
-import torch.nn.functional as F
 
-from typing import List, Optional
+from typing import Optional
 
 
 class CondLayerNormLayer(nn.Module):
@@ -25,4 +23,4 @@ class CondLayerNormLayer(nn.Module):
         u = x.mean(-1, keepdim=True)
         s = (x - u).pow(2).mean(-1, keepdim=True)
         x = (x - u) / torch.sqrt(s + self.variance_epsilon)
-        return weight * x + bias
\ No newline at end of file
+        return weight * x + bias
